unit libparticle;

interface

type acl_type = record
	hi: byte;
	lo: byte;
end;

type acl_packet = record
	acltype: acl_type;
	//Type of the packet defined in acltypes.h */
	type3: array[0..3] of char;
	// Seen flag, needed for get_next_acl_packet_by_type()
	seen: byte;
	//length of data
	len: integer;
	data: ^byte;
end;

type pacl_packet = ^acl_packet;

type cl_packet = record
	// Version number, either 2 or 3
	version: byte;
	// RAUM location
	location: array[0..43] of byte;
        // ID e.g. 1.1.1.1.129.13.x.x
	id: array [0..7] of byte;
	// Sequence number, incremented each time a CL packet is sent.
	seq: byte;
	// Number of allocated acl_packets
	size: integer;
	// Current position in acl_packets
	pos: integer;
	// Counter neeeded for get_next_acl_packet
	i: integer;
	// Pointer to an array of ACL packets. Is resized automatically.
	acl_packets: ^pacl_packet;
end;

type pcl_packet= ^cl_packet;

function create_acl_packet(acltype: pchar; data: pbyte; len: integer) : pacl_packet; cdecl;
function add_acl_packet(c: pcl_packet; a: pacl_packet) :integer; cdecl;
function get_next_acl_packet(c: pcl_packet): pacl_packet; cdecl;
function get_next_acl_packet_by_type(c: pcl_packet; acltype: pchar) : pacl_packet; cdecl;
procedure free_acl_packets(c: pcl_packet); cdecl;
function parse_cl_packet(version: integer; data: pchar; len: integer) : pcl_packet; cdecl;
procedure print_cl_packet(c: pcl_packet); cdecl;
function create_cl_packet(version: integer): pcl_packet; cdecl;
procedure free_cl_packet(c: pcl_packet); cdecl;
function p_socket(port: Word; ComputerID: pbyte): integer; cdecl;
function p_finish(): integer; cdecl;
function p_close(s: integer): integer; cdecl;
function p_recv_raw(s: integer; data: pbyte; maxlen: integer) : integer; cdecl;
function p_send_raw(s: integer; data: pbyte; len: integer) : integer; cdecl;
function p_recv(s: integer; r: integer) : pcl_packet; cdecl; varargs;
function p_send(s: integer; p: pcl_packet ):integer; cdecl;
function p_add_filter(s: integer; f: pchar): integer; cdecl;
function p_rm_filter(s: integer; f: pchar ): integer; cdecl;
function p_add_id_filter(s: integer; f: pbyte): integer; cdecl;
function p_rm_id_filter(s: integer; f: pbyte): integer; cdecl;
function p_add_loc_filter(s: integer; f: pbyte): integer; cdecl;
function p_rm_loc_filter(s: integer; f: pbyte): integer; cdecl;
function p_set_blockingmode(s: integer; mode: byte): integer; cdecl;
function p_send_addressed(s: integer; p: pcl_packet; ID: pbyte): integer;cdecl;
function p_send_acked(s: integer; r: integer; p: pcl_packet; ID: pbyte; number_of_retries: byte; timeout: Longword): integer; cdecl;

implementation

const particlelib='libparticle32.dll';

function create_acl_packet(acltype: pchar; data: pbyte; len: integer) : pacl_packet; cdecl; external particlelib;
function add_acl_packet(c: pcl_packet; a: pacl_packet) :integer; cdecl; external particlelib;
function get_next_acl_packet(c: pcl_packet): pacl_packet; cdecl; external particlelib;
function get_next_acl_packet_by_type(c: pcl_packet; acltype: pchar) : pacl_packet; cdecl; external particlelib;
procedure free_acl_packets(c: pcl_packet); cdecl; external particlelib;
function parse_cl_packet(version: integer; data: pchar; len: integer) : pcl_packet; cdecl; external particlelib;
procedure print_cl_packet(c: pcl_packet); cdecl; external particlelib;
function create_cl_packet(version: integer): pcl_packet; cdecl; external particlelib;
procedure free_cl_packet(c: pcl_packet); cdecl; external particlelib;
function p_socket(port: Word; ComputerID: pbyte): integer; cdecl; external particlelib;
function p_finish(): integer; cdecl; external particlelib;
function p_close(s: integer): integer; cdecl; external particlelib;
function p_recv_raw(s: integer; data: pbyte; maxlen: integer) : integer; cdecl; external particlelib;
function p_send_raw(s: integer; data: pbyte; len: integer) : integer; cdecl; external particlelib;
function p_recv(s: integer; r: integer) : pcl_packet; cdecl; external particlelib;
function p_send(s: integer; p: pcl_packet ):integer; cdecl; external particlelib;
function p_add_filter(s: integer; f: pchar): integer; cdecl; external particlelib;
function p_rm_filter(s: integer; f: pchar ): integer; cdecl; external particlelib;
function p_add_id_filter(s: integer; f: pbyte): integer; cdecl; external particlelib;
function p_rm_id_filter(s: integer; f: pbyte): integer; cdecl; external particlelib;
function p_add_loc_filter(s: integer; f: pbyte): integer; cdecl; external particlelib;
function p_rm_loc_filter(s: integer; f: pbyte): integer; cdecl; external particlelib;
function p_set_blockingmode(s: integer; mode: byte): integer; cdecl; external particlelib;
function p_send_addressed(s: integer; p: pcl_packet; ID: pbyte): integer;cdecl; external particlelib;
function p_send_acked(s: integer; r: integer; p: pcl_packet; ID: pbyte; number_of_retries: byte; timeout: Longword): integer; cdecl; external particlelib;

end.

