/*
*
*	Abstract Communication Layer (ACL) Types for RF Smart-Its
*	types.h
*	TecO, University of Karlsruhe
*	Author:		Michael Beigl
*	Date:		7.3.2002
*	Version:        0.1
*
*	Description: Types are the used to understand communicated data between nodes. Every packet (at ACL layer) follows the following format:
*				  
*								{type_high,type_low,len, {data}}
*
*				 Typical packets are (brackets and commas are for improving readability only:
*			
*								(CHAIR_COMMAND_HI,CHAIR_COMMAND_LO,1,1),(SWITCH_COMMAND_HI,SWITCH_COMMAND_LO,1,15)
*				 which means: I am a chair and my switch is moved 15 times : and results in the following packet
*								133					206			1 1 230					31					1 15
*				 or better readable:                       ACH 1 1 RSW 1 15
*				
*				 All types are 3 chars into 2 bytes coded. use 3_2coding for creating new types
*	
*
*	known bugs:
*	todo:
*
*/

#ifndef _ACLTYPES_H_
#define _ACLTYPES_H_

unsigned int	detected_seqno;





// inbound network commands
#define TIMEBASE_SYNCCOMMAND_HI				242		// CSY
#define TIMEBASE_SYNCCOMMAND_LO				144
#define HELO_COMMAND_HI						115		// CHE
#define HELO_COMMAND_LO						216
#define OLEH_COMMAND_HI						134		// CEH
#define OLEH_COMMAND_LO						32
#define PROG_COMMAND_HI						198		//CPR
#define PROG_COMMAND_LO						88
// Artefacts
#define CHAIR_COMMAND_HI					133	// ACH
#define CHAIR_COMMAND_LO					206
#define SMARTIT_COMMAND_HI					167	// ASM
#define SMARTIT_COMMAND_LO					142
#define DESK_COMMAND_HI						115 // ADE
#define DESK_COMMAND_LO						54

// Raw Sensor value tpyes
#define SWITCH_COMMAND_HI					230	// RSW
#define SWITCH_COMMAND_LO					31
#define ACCL_COMMAND_HI						102	// RAC
#define ACCL_COMMAND_LO						79
	
// Internal context descriptions
#define TEMP_COMMAND_HI						117		// ITE
#define TEMP_COMMAND_LO						190
#define NOISE_COMMAND_HI					160		// INL
#define NOISE_COMMAND_LO					142		
#define MOVE_COMMAND_HI						185		// IMP
#define MOVE_COMMAND_LO						202


#define ACL_TYPE_ACM_H		165
#define ACL_TYPE_ACM_L		14



// other definitions
#define RFVersion 2

#endif